@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2018 Kern Sibbald
+   Copyright (C) 2000-2019 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -631,7 +631,8 @@ bool do_backup(JCR *jcr)
 
    /* Pickup Job termination data */
    stat = wait_for_job_termination(jcr);
-   db_write_batch_file_records(jcr);    /* used by bulk batch file insert */
+
+   flush_file_records(jcr);     /* cached attribute + batch insert */
 
    if (jcr->HasBase) {
       db_commit_base_file_attributes_record(jcr, jcr->db);
@@ -763,6 +764,93 @@ int wait_for_job_termination(JCR *jcr, int timeout)
    return jcr->SDJobStatus;
 }
 
+/* When the job is incomplete, we need to make sure the catalog
+ * is consistent. The JobMedia table should reference Files that
+ * are not in the file table for example.
+ */
+void incomplete_cleanup(JCR *jcr)
+{
+   POOL_MEM buf;
+   char ed1[50], *jmid;
+   bool ok=true;
+   db_int64_ctx job;
+   alist ids(owned_by_alist, 10);
+   alist *pids = &ids;
+
+   if (!jcr->is_incomplete()) {
+      return;
+   }
+
+   edit_int64(jcr->JobId, ed1);
+   /* Get the last valid FileIndex */
+   Mmsg(buf, "SELECT max(FileIndex) FROM File WHERE JobId=%s", ed1);
+   if (!db_sql_query(jcr->db, buf.c_str(), db_int64_handler, &job)) {
+      Jmsg(jcr, M_FATAL, 0, "%s", db_strerror(jcr->db));
+      return;
+   }
+
+   Mmsg(buf, "SELECT JobMediaId FROM JobMedia "
+        "WHERE JobId=%s "
+        "AND (FirstIndex > %lld OR LastIndex > %lld)",
+        ed1, job.value, job.value);
+   if (!db_sql_query(jcr->db, buf.c_str(), db_string_list_handler, &pids)) {
+      Jmsg(jcr, M_FATAL, 0, "%s", db_strerror(jcr->db));
+      return;
+   }
+   /* Nothing to fix */
+   if (pids->size() == 0) {
+      return;
+   }
+
+   db_lock(jcr->db);
+   db_start_transaction(jcr, jcr->db);
+
+   /* Foreach id */
+   foreach_alist(jmid, pids) {
+      JOBMEDIA_DBR jmr;
+      memset(&jmr, 0, sizeof(jmr));
+
+      jmr.JobMediaId = str_to_int64(jmid);
+      if (!db_get_jobmedia_record(jcr, jcr->db, &jmr)) {
+         Jmsg(jcr, M_ERROR, 0, "%s", db_strerror(jcr->db));
+         ok=false;
+         goto bail_out;
+      }
+      if (jmr.FirstIndex > job.value) { /* JobMedia for files not in the catalog */
+         if (jmr.LastIndex > job.value) {
+            Dmsg3(50, "Drop JobMediaId=%d FirstIndex=%lld LastIndex=%lld\n",
+                  jmr.JobMediaId, jmr.FirstIndex, jmr.LastIndex);
+
+         } else {
+            Dmsg3(50, "Incorrect JobMediaId=%d FirstIndex=%lld LastIndex=%lld\n",
+                  jmr.JobMediaId, jmr.FirstIndex, jmr.LastIndex);
+         }
+         Mmsg(buf, "DELETE  FROM JobMedia WHERE JobMediaId=%s", jmid);
+         if (!db_sql_query(jcr->db, buf.c_str(), NULL, NULL)) {
+            ok=false;
+            goto bail_out;
+         }
+      } else if (jmr.LastIndex > job.value) { /* The last index is not in the catalog */
+         Dmsg4(50, "Fix JobMediaId=%d LastIndex=%lld FirstIndex=%lld LastIndex=%lld\n",
+               jmr.JobMediaId, job.value, jmr.FirstIndex, jmr.LastIndex);
+         Mmsg(buf, "UPDATE JobMedia SET LastIndex=%lld WHERE JobMediaId=%s", job.value, jmid);
+         if (!db_sql_query(jcr->db, buf.c_str(), NULL, NULL)) {
+            ok=false;
+            goto bail_out;
+         }
+      } else {
+         Dmsg1(50, "?? JobMedia %d\n", jmr.JobMediaId);
+      }
+   }
+bail_out:
+   if (!ok) {
+      db_sql_query(jcr->db, "ROLLBACK", NULL, NULL);
+      Jmsg(jcr, M_FATAL, 0, _("Unable to cleanup JobMedia records\n"));
+   }
+   db_end_transaction(jcr, jcr->db);
+   db_unlock(jcr->db);
+}
+
 /*
  * Release resources allocated during backup.
  */
@@ -784,6 +872,9 @@ void backup_cleanup(JCR *jcr, int TermCode)
 
    remove_dummy_jobmedia_records(jcr);
 
+   /* cleanup the job media table after an incomplete job, should not be needed */
+   incomplete_cleanup(jcr);
+
    if (jcr->is_JobLevel(L_VIRTUAL_FULL)) {
       vbackup_cleanup(jcr, TermCode);
       return;
@@ -837,7 +928,7 @@ void backup_cleanup(JCR *jcr, int TermCode)
          }
          break;
       case JS_Incomplete:
-         Mmsg(term_msg, _("Backup failed -- incomplete"));
+         Mmsg(term_msg, _("Backup failed -- Incomplete"));
          break;
       case JS_Warnings:
          Mmsg(term_msg, _("Backup OK -- %s"), jcr->StatusErrMsg[0] ? jcr->StatusErrMsg : _("with warnings"));
@@ -1046,7 +1137,8 @@ void update_bootstrap_file(JCR *jcr)
          /* Start output with when and who wrote it */
          bstrftimes(edt, sizeof(edt), time(NULL));
          fprintf(fd, "# %s - %s - %s%s\n", edt, jcr->jr.Job,
-                 level_to_str(edl, sizeof(edl), jcr->getJobLevel()), jcr->since);
+                 level_to_str(edl, sizeof(edl), jcr->getJobLevel()),
+                 jcr->since);
          for (int i=0; i < VolCount; i++) {
             /* Write the record */
             fprintf(fd, "Volume=\"%s\"\n", VolParams[i].VolumeName);
