@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2015 Kern Sibbald
+   Copyright (C) 2000-2019 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -565,6 +565,10 @@ bool do_restore(JCR *jcr)
    /* Print Job Start message */
    Jmsg(jcr, M_INFO, 0, _("Start Restore Job %s\n"), jcr->Job);
 
+   if (jcr->JobIds) {
+      Jmsg(jcr, M_INFO, 0, _("Restoring files from JobId(s) %s\n"), jcr->JobIds);
+   }
+
    if (jcr->client) {
       jcr->sd_calls_client = jcr->client->sd_calls_client;
    }
@@ -685,6 +689,9 @@ void restore_cleanup(JCR *jcr, int TermCode)
       term_msg = _("Restore Canceled");
       terminate_sd_msg_chan_thread(jcr);
       break;
+   case JS_Incomplete:
+      term_msg = _("Restore Incomplete");
+      break;
    default:
       term_msg = term_code;
       sprintf(term_code, _("Inappropriate term code: %c\n"), TermCode);
