@@ -1,7 +1,7 @@
 /*
    Bacula(R) - The Network Backup Solution
 
-   Copyright (C) 2000-2017 Kern Sibbald
+   Copyright (C) 2000-2019 Kern Sibbald
 
    The original author of Bacula is Kern Sibbald, with contributions
    from many others, a complete list can be found in the file AUTHORS.
@@ -488,29 +488,29 @@ bool dir_update_volume_info(DCR *dcr, bool label, bool update_LastWritten,
    if (vol.VolCatType == 0) {
       vol.VolCatType = dev->dev_type;
    }
-   dir->fsend(Update_media, jcr->JobId,
-      VolumeName.c_str(), vol.VolCatJobs, vol.VolCatFiles,
-      vol.VolCatBlocks, edit_uint64(vol.VolCatAmetaBytes, ed1),
-      edit_uint64(vol.VolCatAdataBytes, ed2),
-      edit_uint64(vol.VolCatHoleBytes, ed3),
-      vol.VolCatHoles, vol.VolCatMounts, vol.VolCatErrors,
-      vol.VolCatWrites, edit_uint64(vol.VolCatMaxBytes, ed4),
-      edit_uint64(vol.VolLastWritten, ed5),
-      vol.VolCatStatus, vol.Slot, label,
-      InChanger,                      /* bool in structure */
-      edit_int64(vol.VolReadTime, ed6),
-      edit_int64(vol.VolWriteTime, ed7),
-      edit_uint64(vol.VolFirstWritten, ed8),
-      vol.VolCatType,
-      vol.VolCatParts,
-      vol.VolCatCloudParts,
-      vol.VolLastPartBytes,
-      Enabled,
-      Recycle);
-    Dmsg1(100, ">dird %s", dir->msg);
 
    /* Do not lock device here because it may be locked from label */
    if (!jcr->is_canceled()) {
+      dir->fsend(Update_media, jcr->JobId,
+         VolumeName.c_str(), vol.VolCatJobs, vol.VolCatFiles,
+         vol.VolCatBlocks, edit_uint64(vol.VolCatAmetaBytes, ed1),
+         edit_uint64(vol.VolCatAdataBytes, ed2),
+         edit_uint64(vol.VolCatHoleBytes, ed3),
+         vol.VolCatHoles, vol.VolCatMounts, vol.VolCatErrors,
+         vol.VolCatWrites, edit_uint64(vol.VolCatMaxBytes, ed4),
+         edit_uint64(vol.VolLastWritten, ed5),
+         vol.VolCatStatus, vol.Slot, label,
+         InChanger,                      /* bool in structure */
+         edit_int64(vol.VolReadTime, ed6),
+         edit_int64(vol.VolWriteTime, ed7),
+         edit_uint64(vol.VolFirstWritten, ed8),
+         vol.VolCatType,
+         vol.VolCatParts,
+         vol.VolCatCloudParts,
+         vol.VolLastPartBytes,
+         Enabled,
+         Recycle);
+       Dmsg1(100, ">dird %s", dir->msg);
       /*
        * We sent info directly from dev to the Director.
        *  What the Director sends back is first read into
@@ -544,6 +544,7 @@ bool dir_update_volume_info(DCR *dcr, bool label, bool update_LastWritten,
          dev->VolCatInfo.VolCatWrites = dcr->VolCatInfo.VolCatWrites;
          dev->VolCatInfo.VolCatReads = dcr->VolCatInfo.VolCatReads;
          dev->VolCatInfo.VolEnabled = dcr->VolCatInfo.VolEnabled;
+         dev->VolCatInfo.VolCatMaxBytes = dcr->VolCatInfo.VolCatMaxBytes;
          dev->VolCatInfo.VolRecycle = dcr->VolCatInfo.VolRecycle;
       }
       ok = true;
@@ -591,11 +592,21 @@ bool flush_jobmedia_queue(JCR *jcr)
 
    dir->fsend(Create_jobmedia, jcr->JobId);
    foreach_dlist(item, jcr->jobmedia_queue) {
+      if (jcr->is_JobStatus(JS_Incomplete)) {
+         if (item->VolFirstIndex >= dir->get_lastFileIndex()) {
+            continue;
+         }
+         if (item->VolLastIndex >= dir->get_lastFileIndex()) {
+            item->VolLastIndex = dir->get_lastFileIndex() - 1;
+         }
+      }
       ok = dir->fsend("%u %u %u %u %u %u %lld\n",
          item->VolFirstIndex, item->VolLastIndex,
          item->StartFile, item->EndFile,
          item->StartBlock, item->EndBlock,
          item->VolMediaId);
+      /* Keep track of last FileIndex flushed */
+      dir->set_lastFlushIndex(item->VolLastIndex);
       Dmsg2(400, "sd->dir: ok=%d Jobmedia=%s", ok, dir->msg);
    }
    dir->signal(BNET_EOD);
@@ -667,10 +678,6 @@ bool dir_create_jobmedia_record(DCR *dcr, bool zero)
     *  to the last correctly saved file so that the JobMedia
     *  LastIndex is correct.
     *
-    *  Note: ***FIXME*** though it is not required, we probably
-    *   should also keep a last EndFile and last EndBlock and
-    *   reset them correctly too so that the JobMedia record is
-    *   really correct.
     */
    if (jcr->is_JobStatus(JS_Incomplete)) {
       dcr->VolLastIndex = dir->get_lastFileIndex();
@@ -699,8 +706,8 @@ bool dir_create_jobmedia_record(DCR *dcr, bool zero)
       item->VolMediaId = dcr->VolMediaId;
    }
    jcr->jobmedia_queue->append(item);
-   /* Flush at 100 queue size of 100 jobmedia records */
-   if (zero || jcr->jobmedia_queue->size() >= 100) {
+   /* Flush at queue size of 1000 jobmedia records */
+   if (zero || jcr->jobmedia_queue->size() >= 1000) {
       ok = flush_jobmedia_queue(jcr);
    }
 
